@@ -1,11 +1,11 @@
 'use strict';
 import { Platform } from 'react-native'
 const cheerio = require('react-native-cheerio')
-import {NativeModules} from 'react-native';
+
+import { NativeModules } from 'react-native';
 module.exports = NativeModules.DemoModuleExample;
 
-import DemoModule from './DemoModuleExample';
-
+var DemoModule = require('NativeModules').DemoModuleExample;
 
 var DemoLibrary = {
   checkEmail: function (email) {
