@@ -12,7 +12,7 @@ public class DemoModule extends ReactContextBaseJavaModule {
 
     @Override
     public String getName() {
-        return "DemoModule";
+        return "DemoModuleExample";
     }
 
     public DemoModule(ReactApplicationContext reactContext) {
