@@ -24,10 +24,7 @@ public class DemoPackage implements ReactPackage {
         return modules;
     }
 
-    @Override
-    public List<Class<? extends JavaScriptModule>> createJSModules() {
-        return null;
-    }
+    
 
     @Override
     public List<ViewManager> createViewManagers(ReactApplicationContext reactContext) {
